@@ -62,7 +62,7 @@ class CustomOneSignalReader:
             url=url,
             headers=self._header,
             params={"limit": limit, "total_count": "true", "offset": offset},
-            timeout=30
+            timeout=30,
         )
 
     @request_handler(wait=1, backoff_factor=0.5)
