@@ -1,3 +1,7 @@
+# pylint: disable=too-many-nested-blocks,too-many-locals,no-name-in-module,import-error,broad-except,lost-exception,inconsistent-return-statements,too-many-branches,too-many-statements
+"""
+ZOHO CRM READER MODULE
+"""
 import os
 import time
 
@@ -33,11 +37,13 @@ class CustomZohoReader:
         This method handles the directories and environments as well as the OAth Client.
         """
         # create file for app log without needing root and OS dependency
+        current_dir = os.getcwd()
         try:
-            os.mkdir(
-                f"{os.getcwd()}/{self.creds.get('application_log_file_path').replace('./', '')}"
+            app_log_file_path = self.creds.get("application_log_file_path").replace(
+                "./", ""
             )
-            log_file_path = f"{os.getcwd()}/{self.creds.get('application_log_file_path').replace('./', '')}/{'client_library.log'}"
+            os.mkdir(f"{current_dir}/{app_log_file_path}")
+            log_file_path = f"{current_dir}/{app_log_file_path}/{'client_library.log'}"
             if not os.path.exists(log_file_path):
                 with open(log_file_path, "a") as _file:
                     _file.write("")
@@ -218,7 +224,7 @@ class CustomZohoReader:
 
             try:
                 record["last_activity_time"] = module_object.last_activity_time
-            except:
+            except Exception:
                 print("The last_activity_time is not available.")
 
             if self.module == "Deals":
@@ -285,7 +291,7 @@ class CustomZohoReader:
                                     if field_name not in record.keys():
                                         try:
                                             field_value = module_object.field_name
-                                        except:
+                                        except Exception:
                                             field_value = module_object.get_field_value(
                                                 field_name
                                             )
@@ -309,7 +315,8 @@ class CustomZohoReader:
                             data_set = []
 
                             page += 1
-                            # get_records dies very easily if overused, so permanent sleep method is recommended
+                            # get_records dies very easily if overused,
+                            # so permanent sleep method is recommended
                             time.sleep(1)
                             print("Waiting for 1 second.")
 
@@ -332,7 +339,7 @@ class CustomZohoReader:
                                     if field_name not in record.keys():
                                         try:
                                             field_value = module_object.field_name
-                                        except:
+                                        except Exception:
                                             field_value = module_object.get_field_value(
                                                 field_name
                                             )
@@ -346,7 +353,8 @@ class CustomZohoReader:
                                 loop_count += 1
                             page += 1
 
-                            # get_records dies very easily if overused, so permanent sleep method is recommended
+                            # get_records dies very easily if overused,
+                            # so permanent sleep method is recommended
                             time.sleep(20)
                             print("Waiting for 20 seconds.")
 
